
from mandaye.auth.saml2 import SAML2Auth
from mandaye.configs import saml2 as saml2_config

from mandaye_vincennes import config
from mandaye_vincennes.filters import vincennes

form_values = {
        'login_url': '/sezhame/page/connexion-abonne',
        'form_attrs': { 'id': 'dk-opac15-login-form', },
        'post_fields': ['user', 'password'],
        'username_field': 'user',
        'password_field': 'password',
}

saml2_config.IDP_METADATA = "https://sso-vincennes.dev.entrouvert.org/idp/saml2/metadata"
saml2_config.SAML_SIGNATURE_PUBLIC_KEY = config.SAML_SIGNATURE_PUBLIC_KEY
saml2_config.SAML_SIGNATURE_PRIVATE_KEY = config.SAML_SIGNATURE_PRIVATE_KEY


auth = SAML2Auth(form_values, 'biblio', saml2_config)
filters = vincennes.Biblio()

biblio_mapping = [
        {
            'path': r'/(?!/*mandaye)',
            'on_response': [
                {
                    'filter': filters.resp_html,
                    'content-types': ['application/x-javascript', 'text/html', 'text/css'],
                    'decompress': False,
                    },
                ],
            },
        {
            'path': r'/sezhame',
            'on_response': [{
                'filter': filters.resp_multicompte_html,
                'content-types': ['text/html'],
                'values': {
                    'associate_url': '/mandaye/associate',
                    'template': 'biblio/multicompte.html',
                    'nosso_template': 'biblio/nosso.html',
                    'site_name': 'biblio'
                    },
                },]
        },
        {
            'path': r'/mandaye/login$',
            'method': 'GET',
            'response': [{
                'filter': auth.login,
                'values': {
                    'associate_url': '/mandaye/associate',
                    },
                'condition': 'response.code==302',
                },]
        },
        {
            'path': r'/mandaye/sso$',
            'method': 'GET',
            'response': [{
                'filter': auth.sso,
                },]
        },
        {
            'path': r'/mandaye/slo$',
            'method': 'GET',
            'response': [{
                'filter': auth.slo,
                },]
        },
        {
            'path': r'%s$' % auth.config.END_POINTS_PATH['metadata'],
            'method': 'GET',
            'response': [{
                'filter': auth.metadata,
                }]
            },
        {
                'path': r'%s$' % auth.config.END_POINTS_PATH['single_sign_on_post'],
                'method': 'POST',
                'response': [{
                    'filter': auth.single_sign_on_post,
                    'values': {
                        'login_url': '/mandaye/login',
                        'next_url': '/sezhame'
                        }
                    }]
                },
        {
                'path': r'%s$' % auth.config.END_POINTS_PATH['single_logout'],
                'method': 'GET',
                'response': [{
                    'filter': auth.single_logout,
                    }]
                },
        {
                'path': r'%s$' % auth.config.END_POINTS_PATH['single_logout_return'],
                'method': 'GET',
                'response': [{
                    'filter': auth.single_logout_return,
                    'values': {
                        'next_url': '/shezame'
                        }
                    }]
                },
        {
            'path': r'/mandaye/associate$',
            'method': 'GET',
            'target': '/sezhame/page/connexion-abonne',
            'on_response': [{
                'filter': filters.resp_associate_login,
                'values': {
                    'action': '/mandaye/associate',
                    'template': 'biblio/associate.html',
                    'badlogin_msg': "Num&eacute;ro de carte ou/et mot de passe incorrects",
                    'failed_msg': "Vos identifiants pour la biblioth&egrave;que ne fonctionnent plus ! Merci de les ressaisir.",
                    },
                },
                {
                'filter': filters.resp_multicompte_html,
                'values': {
                    'associate_url': '/mandaye/associate',
                    'template': 'biblio/multicompte.html',
                    'nosso_template': 'biblio/nosso.html',
                    'site_name': 'biblio'
                    },

                },]
        },
        {
            'path':  r'/mandaye/associate$',
            'method': 'POST',
            'response': [
                {
                    'filter': auth.associate_submit,
                    'values': {
                        'connection_url': '/mandaye/sso',
                        'associate_url': '/mandaye/associate',
                        },
                    'condition': "response.code==302"
                    },
                ]
        },
        {
                'path': r'/sezhame/page/connexion-abonne$',
                'method': 'GET',
                'on_response': [{
                'filter': filters.resp_html_login_page,
                'values': {
                    'connection_url': '/mandaye/sso',
                    'template': 'biblio/login.html',
                    'title': 'Connexion via votre compte citoyen'
                    }
                }]
        },
        {
            'path': r'/mandaye/change_user$',
            'method': 'GET',
            'response': [{
                'filter': auth.change_user,
                'values': {
                    'associate_url': '/mandaye/associate',
                    },
                }]
        },
        {
            'path': r'/mandaye/disassociate$',
            'method': 'GET',
            'response': [{
                'filter': auth.disassociate,
                'values': {
                    'next_url': '/sezhame',
                    },
                }]
        },
        {
            'path': r'/sezhame/logout$',
            'on_response': [{'filter': auth.slo}]
        },
]


