
from mandaye.configs import saml2 as saml2_config

from mandaye_vincennes import config
from mandaye_vincennes.auth.espacefamille import EspaceFamilleAuth
from mandaye_vincennes.filters.vincennes import EspaceFamille

folder_target = '/vincennes-noredirect'
filters = EspaceFamille()

form_values = {
        'post_url': '%s/login.do' % folder_target,
        'login_url': '%s/index.do' % folder_target,
        'form_attrs': { 'action': 'login.do', },
        'post_fields': ['codeFamille', 'motDePasse'],
        'username_field': 'codeFamille',
        'password_field': 'motDePasse'
}

saml2_config.IDP_METADATA = "https://sso-vincennes.dev.entrouvert.org/idp/saml2/metadata"
saml2_config.SAML_SIGNATURE_PUBLIC_KEY = config.SAML_SIGNATURE_PUBLIC_KEY
saml2_config.SAML_SIGNATURE_PRIVATE_KEY = config.SAML_SIGNATURE_PRIVATE_KEY
saml2_config.SP_LOGOUT_URL = "%s/deconnexion.do" % folder_target

auth = EspaceFamilleAuth(form_values, 'espace_famille', saml2_config)

famille_mapping = [
        {
            'path': r'/$',
            'method': 'GET',
            'redirect': '%s/index.do' % folder_target
            },
        {
            'path': r'/(?!/*mandaye|.*/associate)',
            'method': 'GET',
            'on_response': [
                {
                    'filter': filters.resp_disassociate,
                    'content-types': ['text/html'],
                    'values': {'site_name': 'espace_famille'}
                    },
                ]
            },
        {
            'path': r"/(?!.*/associate)",
            'on_response': [{
                'filter': filters.resp_login_page,
                'content-types': ['text/html'],
                'values': {
                    'connection_url': '/mandaye/sso',
                    'template': 'famille/login.html',
                    'title': 'Connexion via votre compte citoyen'
                    }
                },]
            },
        {
            'path': r'/mandaye/login$',
            'method': 'GET',
            'response': [{
                'filter': auth.login,
                'values': {
                    'associate_url': '%s/associate' % folder_target,
                    },
                'condition': 'response.code==302',
                },]
            },
        {
            'path': r'%s/associate$' % folder_target,
            'method': 'GET',
            'target': '%s/index.do' % folder_target,
            'on_response': [{
                'filter': filters.resp_associate,
                'values': {
                    'action': '%s/associate' % folder_target,
                    'template': 'famille/associate.html',
                    'title': 'Associer un compte au compte citoyen de Vincennes',
                    'badlogin_msg': "Code famille et/ou mot de passe incorrects",
                    'failed_msg': "Vos identifiants pour l'espace famille ne fonctionnent plus ! Merci de les ressaisir.",
                    },
                }]
            },
        {
                'path':  r'%s/associate$' % folder_target,
                'method': 'POST',
                'response': [
                    {
                        'filter': auth.associate_submit,
                        'values': {
                            'associate_url': '%s/associate' % folder_target,
                            'connection_url': '/mandaye/sso',
                            },
                        'condition': "response.code==302"
                        },
                    ]
                },
        {
                'path': r'/mandaye/sso$',
                'method': 'GET',
                'response': [{
                    'filter': auth.sso,
                    'values': {
                        'next_url': '/mandaye/login',
                        }
                    }]
                },
        {
                'path': r'/mandaye/slo$',
                'method': 'GET',
                'response': [{
                'filter': auth.slo,
                },]
                },
        {
            'path': r'%s$' % auth.config.END_POINTS_PATH['metadata'],
            'method': 'GET',
            'response': [{
                'filter': auth.metadata,
                }]
            },
        {
                'path': r'%s$' % auth.config.END_POINTS_PATH['single_sign_on_post'],
                'method': 'POST',
                'response': [{
                    'filter': auth.single_sign_on_post,
                    'values': {
                        'login_url': '/mandaye/login',
                        }
                    }]
                },
        {
                'path': r'%s$' % auth.config.END_POINTS_PATH['single_logout'],
                'method': 'GET',
                'response': [{
                    'filter': auth.single_logout,
                    }]
                },
        {
                'path': r'%s$' % auth.config.END_POINTS_PATH['single_logout_return'],
                'method': 'GET',
                'response': [{
                    'filter': auth.single_logout_return,
                    'values': {
                        'next_url': '/'
                        }
                    }]
                },
        {
                'path': r'%s/deconnexion.do$' % folder_target,
                'method': 'POST',
                'on_response': [{'filter': auth.slo},]
                },
        {
                'path': r'/mandaye/disassociate$',
                'method': 'GET',
                'response': [{
                    'filter': auth.disassociate,
                    'values': {
                        'next_url': '%s/affichage_accueil_prive.do' % folder_target,
                        },
                    }]
                },
        ]

