
from mandaye.auth.saml2 import SAML2Auth
from mandaye.configs import saml2 as saml2_config

from mandaye_vincennes import config
from mandaye_vincennes.filters.vincennes import Duonet


filters = Duonet()
duonet_key = 'CV4j27Em0dM%3d'

form_values = {
        'login_url': 'Connect.aspx?key=%s' % duonet_key,
        'form_attrs': {'name': 'form1'},
        'post_fields': ['txtNomFoyer', 'txtDateNaissance', 'txtCode'],
        'username_field': 'txtNomFoyer',
        'password_field': 'txtCode'
        }

saml2_config.IDP_METADATA = "https://sso-vincennes.dev.entrouvert.org/idp/saml2/metadata"
saml2_config.SAML_SIGNATURE_PUBLIC_KEY = config.SAML_SIGNATURE_PUBLIC_KEY
saml2_config.SAML_SIGNATURE_PRIVATE_KEY = config.SAML_SIGNATURE_PRIVATE_KEY

auth = SAML2Auth(form_values, 'duonet', saml2_config)

duonet_mapping = [
        {
            'path': r'/',
            'on_response': [
                {
                    'content-types': ['text/html'],
                    'filter': filters.resp_global_html,
                    'values': {
                        'associate_url': '/associate',
                        'nosso_template': 'duonet/nosso.html',
                        'site_name': 'duonet'
                        },
                    },
                ]
            },
        {
            'path': r'/mandaye/logout$',
            'method': 'GET',
            'response': [{
                'filter': filters.logout,
                'values': {
                    'index_url': '/Connect.aspx?key=%s' % duonet_key,
                    },
                },]
            },
        {
            'path': r'/vincennes/login$',
            'method': 'GET',
            'response': [{
                'filter': auth.login,
                'values': {
                    'associate_url': '/associate',
                    },
                'condition': 'response.code==302',
                },]
            },
        {
                'path': r'/associate$',
                'method': 'GET',
                'target': '/Connect.aspx?key=%s' % duonet_key,
                'on_response': [{
                    'filter': filters.resp_associate,
                    'values': {
                        'action': '/associate',
                        'template': 'duonet/associate.html',
                        'badlogin_msg': "Mauvais identifiants",
                        'failed_msg': "Vos identifiants pour le conservatoire ne fonctionnent plus ! Merci de les ressaisir.",
                        },
                    }]
                },
        {
                'path':  r'/associate$',
                'method': 'POST',
                'response': [
                    {
                        'filter': auth.associate_submit,
                        'values': {
                            'connection_url': '/mandaye/sso',
                            'associate_url': '/associate',
                            },
                        'condition': "response.code==302"
                        },
                    ]
                },
        {
                'path': r'/mandaye/sso$',
                'method': 'GET',
                'response': [{
                    'filter': auth.sso,
                    }]
                },
        {
                'path': r'/mandaye/slo$',
                'method': 'GET',
                'response': [{
                'filter': auth.slo,
                },]
                },
        {
            'path': r'%s$' % auth.config.END_POINTS_PATH['metadata'],
            'method': 'GET',
            'response': [{
                'filter': auth.metadata,
                }]
            },
        {
                'path': r'%s$' % auth.config.END_POINTS_PATH['single_sign_on_post'],
                'method': 'POST',
                'response': [{
                    'filter': auth.single_sign_on_post,
                    'values': {
                        'login_url': '/vincennes/login',
                        'next_url': '/Default.aspx'
                        }
                    }]
                },
        {
                'path': r'%s$' % auth.config.END_POINTS_PATH['single_logout'],
                'method': 'GET',
                'response': [{
                    'filter': auth.single_logout,
                    }]
                },
        {
                'path': r'%s$' % auth.config.END_POINTS_PATH['single_logout_return'],
                'method': 'GET',
                'response': [{
                    'filter': auth.single_logout_return,
                    'values': {
                        'next_url': '/'
                        }
                    }]
                },
        {
                'path': r'/mandaye/disassociate$',
                'method': 'GET',
                'response': [{
                    'filter': auth.disassociate,
                    'values': {
                        'next_url': '/Default.aspx',
                        },
                    }]
                },
        {
                'path': r'/Connect.aspx$',
                'method': 'GET',
                'on_response': [{
                    'filter': filters.resp_login_page,
                    'values': {
                        'connection_url': '/mandaye/sso',
                        'template': 'duonet/login.html',
                        }
                    }]
                },
        {
                'path': r'/$',
                'method': 'GET',
                'target': '/Connect.aspx?key=%s' % duonet_key,
                'on_response': [{
                    'filter': filters.resp_login_page,
                    'values': {
                        'connection_url': '/mandaye/sso',
                        'template': 'duonet/login.html',
                        }
                    }]
                },
        ]


